# yum-elrepo Cookbook

[![Cookbook Version](https://img.shields.io/cookbook/v/yum-elrepo.svg)](https://supermarket.chef.io/cookbooks/yum-elrepo)
[![CI State](https://github.com/sous-chefs/yum-elrepo/workflows/ci/badge.svg)](https://github.com/sous-chefs/yum-elrepo/actions?query=workflow%3Aci)
[![OpenCollective](https://opencollective.com/sous-chefs/backers/badge.svg)](#backers)
[![OpenCollective](https://opencollective.com/sous-chefs/sponsors/badge.svg)](#sponsors)
[![License](https://img.shields.io/badge/License-Apache%202.0-green.svg)](https://opensource.org/licenses/Apache-2.0)

The yum-elrepo cookbook takes over management of the default repositoryids used by elrepo. It allows attribute manipulation of `elrepo`.

## Maintainers

This cookbook is maintained by the Sous Chefs. The Sous Chefs are a community of Chef cookbook maintainers working together to maintain important cookbooks. If you’d like to know more please visit sous-chefs.org or come chat with us on the Chef Community Slack in #sous-chefs.

## Requirements

### Platforms

- RHEL/CentOS and derivatives
- Fedora

### Chef

- Chef 12.14+

### Cookbooks

- none

## Attributes

The following attributes are set by default

```ruby
default['yum']['elrepo']['baseurl'] = 'http://elrepo.org/mirrors-elrepo.el6'
default['yum']['elrepo']['baseurl'] = 'ELRepo.org Yum Repository'
default['yum']['elrepo']['gpgkey'] = 'http://elrepo.org/RPM-GPG-KEY-elrepo.org'
default['yum']['elrepo']['enabled'] = true
```

## Recipes

- default - Walks through node attributes and feeds a yum_resource
- parameters. The following is an example a resource generated by the
- recipe during compilation.

```ruby
  yum_repository 'elrepo' do
    mirrorlist 'http://elrepo.org/mirrors-elrepo.el6'
    description 'ELRepo.org Yum Repository'
    enabled true
    gpgcheck true
    gpgkey 'http://elrepo.org/RPM-GPG-KEY-elrepo.org'
  end
```

## Usage Example

To disable the elrepo repository through a Role or Environment definition

```ruby
default_attributes(
  :yum => {
    :elrepo => {
      :enabled => {
        false
       }
     }
   }
 )
```

To enable the elrepo repository with a wrapper cookbook, place the following in a recipe:

```ruby
node.default['yum']['elrepo']['enabled'] = true
include_recipe 'yum-elrepo'
```

## More Examples

Point the elrepo repositories at an internally hosted server.

```ruby
node.default['yum']['elrepo']['enabled'] = true
node.default['yum']['elrepo']['baseurl'] = 'https://internal.example.com/elrepo'
node.default['yum']['elrepo']['sslverify'] = false

include_recipe 'yum-elrepo'
```

## Contributors

This project exists thanks to all the people who [contribute.](https://opencollective.com/sous-chefs/contributors.svg?width=890&button=false)

### Backers

Thank you to all our backers!

![https://opencollective.com/sous-chefs#backers](https://opencollective.com/sous-chefs/backers.svg?width=600&avatarHeight=40)

### Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website.

![https://opencollective.com/sous-chefs/sponsor/0/website](https://opencollective.com/sous-chefs/sponsor/0/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/1/website](https://opencollective.com/sous-chefs/sponsor/1/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/2/website](https://opencollective.com/sous-chefs/sponsor/2/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/3/website](https://opencollective.com/sous-chefs/sponsor/3/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/4/website](https://opencollective.com/sous-chefs/sponsor/4/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/5/website](https://opencollective.com/sous-chefs/sponsor/5/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/6/website](https://opencollective.com/sous-chefs/sponsor/6/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/7/website](https://opencollective.com/sous-chefs/sponsor/7/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/8/website](https://opencollective.com/sous-chefs/sponsor/8/avatar.svg?avatarHeight=100)
![https://opencollective.com/sous-chefs/sponsor/9/website](https://opencollective.com/sous-chefs/sponsor/9/avatar.svg?avatarHeight=100)
